@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -34,13 +34,12 @@ void data_file(char *tmp)
    FILE *fp_in;
 
    char accdia[11], acchora[9], accuser[MAXLEN], accip[MAXLEN], accurl[MAXLEN], accbytes[12], accelap[10];
-   char oldaccdia[11], oldacchora[9], oldaccip[MAXLEN], wdir[MAXLEN], per1[MAXLEN];
+   char oldaccdia[11], oldacchora[9], oldaccip[MAXLEN];
    char dirname[MAXLEN], wdirname[MAXLEN], oldurl[MAXLEN], oldaccuser[MAXLEN];
    char olduser[MAXLEN], oldmsg[50], acccode[50], oldaccelap[10], oldacccode[50];
    char ipantes[MAXLEN], nameantes[MAXLEN]; 
    char accsmart[MAXLEN];
    char Msg[MAXLEN];
-   int  smartfilter=0;
    char wcrc[50];
    char crc2[50];
    char wdname[MAXLEN];
@@ -53,7 +52,6 @@ void data_file(char *tmp)
    long long int rtotal=0;
    long long int incache=0;
    long long int oucache=0;
-   char *s;
 
    ipantes[0]='\0';
    nameantes[0]='\0';
@@ -94,7 +92,8 @@ void data_file(char *tmp)
                strcpy(ipantes,accip);
                ip2name(accip);
                strcpy(nameantes,accip);
-            } else strcpy(accip,nameantes);
+            } 
+	    else strcpy(accip,nameantes);
          }
    
          if(!rtotal){
@@ -110,19 +109,17 @@ void data_file(char *tmp)
    
          if(strcmp(oldurl,accurl) != 0 || strcmp(oldaccuser,accuser) != 0){
             strcpy(oldmsg,"OK");
-            if(strstr(oldacccode,"DENIED") != 0)
-               sprintf(oldmsg,"%s",text[46]);
+            if(strstr(oldacccode,"DENIED") != 0) strcpy(oldmsg,text[46]);
             strcpy(wdirname,dirname);
             gravatmp(oldaccuser,wdirname,oldurl,nacc,nbytes,oldmsg,nelap,indexonly,incache,oucache);
             strcpy(wdirname,dirname);
-            saverecs2(wdirname,oldaccuser,nacc,oldurl,nbytes,oldaccip,oldacchora,oldaccdia,nelap,incache,oucache);
+            saverecs(wdirname,oldaccuser,nacc,oldurl,nbytes,oldaccip,oldacchora,oldaccdia,nelap,incache,oucache);
             nacc=0;
             nbytes=0;
             nelap=0;
             incache=0;
             oucache=0;
-            if(strcmp(oldaccuser,accuser) != 0)
-               ind2=0;
+            if(strcmp(oldaccuser,accuser) != 0) ind2=0;
          }
 
          nacc++;
@@ -132,9 +129,8 @@ void data_file(char *tmp)
          strcpy(wcrc,acccode);
          getword(crc2,wcrc,'/');
 
-         if(strstr(crc2,"MISS") != 0)
-            oucache+=my_atoll(accbytes);
-          else incache+=my_atoll(accbytes);
+         if(strstr(crc2,"MISS") != 0) oucache+=my_atoll(accbytes);
+         else incache+=my_atoll(accbytes);
    
          strcpy(oldurl,accurl);
          strcpy(oldaccuser,accuser);
@@ -153,10 +149,9 @@ void data_file(char *tmp)
       sprintf(Msg,"Datafile %s successfully",DataFile);
       debuga(Msg);
    }
-   return;
 }
 
-void saverecs2(char *dirname, char *user, long long int nacc, char *url, long long int nbytes, char *ip, char *hora, char *dia, long long int nelap, long long int incache, long long int oucache)
+void saverecs(char *dirname, char *user, long long int nacc, char *url, long long int nbytes, char *ip, char *hora, char *dia, long long int nelap, long long int incache, long long int oucache)
 {
 
    FILE *fp_ou;
@@ -187,8 +182,7 @@ void saverecs2(char *dirname, char *user, long long int nacc, char *url, long lo
    }
    if(strstr(DataFileFields,"url") != 0) {
       strcpy(name,url);
-      if (strcmp(DataFileUrl,"ip") == 0)
-         name2ip(name);
+      if (strcmp(DataFileUrl,"ip") == 0) name2ip(name);
       strncat(reg,name,strlen(name));
       strncat(reg,DataFileDelimiter,1);
    }
@@ -217,7 +211,4 @@ void saverecs2(char *dirname, char *user, long long int nacc, char *url, long lo
    fputs(reg,fp_ou);
 
    fclose(fp_ou);
-
-   return;
-
 }
