@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -31,13 +31,11 @@ void gen_denied_report()
    FILE *fp_in = NULL, *fp_ou = NULL;
       
    char url[MAXLEN];
-   char html[MAXLEN];
    char html2[MAXLEN];
    char denied_in[MAXLEN];
-   char denied_ou[MAXLEN];
    char per[MAXLEN];
    char report[MAXLEN];
-   char periodo[100];
+   char period[100];
    char ip[MAXLEN];
    char oip[MAXLEN];
    char user[MAXLEN];
@@ -45,7 +43,6 @@ void gen_denied_report()
    char ouser2[MAXLEN];
    char data[15];
    char hora[15];
-   char ftime[128];
    char *str;
    int  z=0;
    int  count=0;
@@ -58,7 +55,7 @@ void gen_denied_report()
       return;
    }
 
-   sprintf(per,"%s/periodo",dirname);
+   sprintf(per,"%s/period",dirname);
    sprintf(report,"%s/denied.html",dirname);
 
    if ((fp_in = fopen(per, "r")) == 0) {
@@ -66,7 +63,7 @@ void gen_denied_report()
       exit(1);
    }
 
-   fgets(periodo,sizeof(periodo),fp_in);
+   fgets(period,sizeof(period),fp_in);
    fclose(fp_in);
 
    if((fp_in=fopen(denied_in,"r"))==NULL) {
@@ -79,45 +76,29 @@ void gen_denied_report()
      exit(1);
    }
 
-   fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_ou);
-   fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_ou);
-   fputs("<html>\n",fp_ou);
-   fputs("<head>\n",fp_ou);
-   sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
-   fputs(html,fp_ou);
+   fprintf(fp_ou, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n<html>\n<head>\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
    css(fp_ou);
    fputs("</head>\n",fp_ou);
-
-   sprintf(url,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
-   fputs(url,fp_ou);
-
-   fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
-
-   if(strlen(LogoImage) > 0) {
-      fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ou);
-      sprintf(url,"<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n",LogoImage,Width,Height,LogoText);
-      fputs(url,fp_ou);
-      fputs("<tr><td height=\"5\"></td></tr>\n",fp_ou);
-      fputs("</table>\n",fp_ou);
-   }
+   fprintf(fp_ou,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
+   if(strlen(LogoImage) > 0) fprintf(fp_ou, "<center><table cellpadding=\"0\" cellspacing=\"0\">\n<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n<tr><td height=\"5\"></td></tr>\n</table>\n",LogoImage,Width,Height,LogoText);
 
    if(strcmp(IndexTree,"date") == 0)
       show_sarg(fp_ou, "../../..");
    else
       show_sarg(fp_ou, "..");
+
+   fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
    sprintf(url,"<tr><th class=\"title\">%s</b></th></tr>\n",Title);
    fputs(url,fp_ou);
 
-   sprintf(url,"<tr><td class=\"header\">%s: %s</td></tr>\n",text[89],periodo);
+   sprintf(url,"<tr><td class=\"header\">%s: %s</td></tr>\n",text[89],period);
    fputs(url,fp_ou);
-   sprintf(url,"<tr><th class=\"header3\">%s %s</th></tr>\n",text[46],text[55]);
+   sprintf(url,"<tr><th class=\"header3\">%s</th></tr>\n",text[46]);
    fputs(url,fp_ou);
    fputs("</table></center>\n",fp_ou);
 
    fputs("<center><table cellpadding=0 cellspacing=2>\n",fp_ou);
    fputs("<tr><td></td></tr>\n",fp_ou);
-   fputs("<tr><td></td></tr>\n",fp_ou);
-   fputs("<tr><td></td></tr>\n",fp_ou);
    sprintf(url,"<tr><th class=\"header\">%s</th><th class=\"header\">%s</th><th class=\"header\">%s</th><th class=\"header\">%s</th></tr>\n",text[98],text[111],text[110],text[91]);
    fputs(url,fp_ou);
 
