@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -25,36 +25,34 @@
 
 #include "include/conf.h"
 
-int vhexclude(char *excludefile, char *ip)
+int vhexclude(char *excludefile, char *url)
 {
 
    char whost[1024];
-   char wip1[1024], wip2[1024];
-   char sn1[4], sn2[4], sn3[4];
    char str[strlen(excludefile)];
+   char wurl[strlen(url)];
+   char wurl2[strlen(url)];
 
    whost[0]='\0';
    strcpy(str,excludefile);
+   strcpy(wurl,url);
+
    getword(whost,str,' ');
    
-   while(strcmp(whost,"*FIM*") != 0) {
-      if(strcmp(ip,whost) ==0)
+   if(strchr(wurl,':') != 0) {
+      getword(warea,wurl,':');
+      strcpy(wurl,warea);
+   }
+
+   while(strcmp(whost,"*END*") != 0) {
+      if(strcmp(wurl,whost) == 0)
          return(0);
-
-      strcpy(wip1,ip);
-      getword(sn1,wip1,'.');
-      getword(sn2,wip1,'.');
-      getword(sn3,wip1,'.');
-
-      sprintf(wip1,"%s.%s.%s.0",sn1,sn2,sn3);
-      sprintf(wip2,"%s.%s.0.0",sn1,sn2);
-
-      if(strstr(whost,wip1) !=0)
-         return(0);
-
-      if(strstr(whost,wip2) !=0)
-         return(0);
-
+      if(strchr(whost,'*') != 0) {
+         getword(warea,whost,'.');
+         getword(warea,wurl,'.');
+         if(strcmp(wurl,whost) == 0)
+            return(0);
+      }
       getword(whost,str,' ');
    }
 
