@@ -190,7 +190,7 @@ void parmtest(char *buf)
 
       if(strstr(buf,"date_format") != 0) {
          getword(wbuf,buf,' ');
-         strcpy(DateFormat,buf);
+         strncpy(DateFormat,buf,1);
          fixnone(DateFormat);
          return;
       }
@@ -226,10 +226,12 @@ void parmtest(char *buf)
       }
 
       if(strstr(buf,"access_log") != 0) {
-         getword(wbuf,buf,' ');
-         strcpy(AccessLog,buf);
-         fixnone(AccessLog);
-         return;
+	 if(strstr(buf,"realtime_access_log_lines") == 0) {
+            getword(wbuf,buf,' ');
+            strcpy(AccessLog,buf);
+            fixnone(AccessLog);
+            return;
+         }
       }
 
       if(strstr(buf,"useragent_log") != 0) {
@@ -521,6 +523,13 @@ void parmtest(char *buf)
          return;
       }
 
+      if(strstr(buf,"bytes_in_sites_users_report") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(BytesInSitesUsersReport,buf);
+         fixnone(BytesInSitesUsersReport);
+         return;
+      }
+
       if(strstr(buf,"user_report_fields") != 0) {
          getword(wbuf,buf,' ');
          strcpy(UserReportFields,buf);
@@ -528,10 +537,10 @@ void parmtest(char *buf)
          return;
       }
 
-      if(strstr(buf,"site_user_time_date_type") != 0) {
+      if(strstr(buf,"bytes_in_sites_users_report") != 0) {
          getword(wbuf,buf,' ');
-         strcpy(SiteUserTimeDateType,buf);
-         fixnone(SiteUserTimeDateType);
+         strcpy(BytesInSitesUsersReport,buf);
+         fixnone(BytesInSitesUsersReport);
          return;
       }
 
@@ -799,9 +808,12 @@ void getconf()
       if(debugm)
          printf("SYSCONFDIR %s",buf);
 
-      if(strncmp(buf,"#",1) == 0)
+      if(strncmp(buf,"#",1) == 0 || strncmp(buf,"\n",1) == 0)
          continue;
 
+      if(debugz)
+         printf("SARG: TAG: %s",buf);
+
       parmtest(buf);
 
    }
