@@ -39,14 +39,12 @@ int x1;
 char *font1 = SYSCONFDIR"/fonts/FreeSans.ttf";
 char s[15];
 
-#ifdef HAVE_GD
-#ifdef HAVE_ICONV_H
+#if defined(HAVE_GD) && defined(HAVE_ICONV_H) && defined(gdFTEX_Unicode)
 #include <iconv.h>
 #define SARGgdImageStringFT I18NgdImageStringFT
 
-BGD_DECLARE(char *) I18NgdImageStringFT (gdImage * im, int *brect, int fg, char *fontlist,
-                         double ptsize, double angle, int x, int y,
-                                                 char *string)
+char * I18NgdImageStringFT (gdImage * im, int *brect, int fg, char *fontlist, 
+                         double ptsize, double angle, int x, int y, char *string)
 {
  iconv_t localtoutf;
  char *sstring, *str, *sstr, *retval;
@@ -71,7 +69,6 @@ BGD_DECLARE(char *) I18NgdImageStringFT (gdImage * im, int *brect, int fg, char
 #else
 #define SARGgdImageStringFT gdImageStringFT
 #endif
-#endif
 
 void *bar(long long int *n)
 {     
