@@ -36,7 +36,7 @@ void htmlrel()
    long long int incache=0, oucache=0, tnincache=0, tnoucache=0, twork=0, twork2=0;
    char arqin[MAXLEN], arqou[MAXLEN], arqper[MAXLEN], arqip[MAXLEN];
    char nacc[20], nbytes[20], url[1024], purl[1024], tmsg[50], tmsg2[50], nelap[20], csort[MAXLEN];
-   char periodo[MAXLEN], usuario[MAXLEN], wusuario[MAXLEN], u2[MAXLEN], duser[MAXLEN];
+   char period[MAXLEN], usuario[MAXLEN], wusuario[MAXLEN], u2[MAXLEN], duser[MAXLEN];
    char userbytes[20], userelap[20], userurl[1024], userhora[9], userdia[9];
    char user_ip[MAXLEN], olduserip[MAXLEN], tmp2[MAXLEN], tmp3[MAXLEN], incac[20], oucac[20];
    char denied_report[255], name2[MAXLEN];
@@ -59,18 +59,18 @@ void htmlrel()
    strcat(tmp3,"/sargtmp.log");
 
    strcpy(arqper,dirname);
-   strcat(arqper,"/periodo");
+   strcat(arqper,"/period");
 
    if ((fp_in = fopen(arqper, "r")) == 0){
       fprintf(stderr, "SARG: (html1) %s: %s\n",text[45],arqper);
       exit(1);
    }
 
-   fgets(periodo,sizeof(periodo),fp_in);
+   fgets(period,sizeof(period),fp_in);
    fclose(fp_in);
 
    strcpy(arqper,dirname);
-   strcat(arqper,"/geral");
+   strcat(arqper,"/general");
 
    if ((fp_in = fopen(arqper, "r")) == 0){
       fprintf(stderr, "SARG: (html2) %s: %s\n",text[45],arqper);
@@ -232,7 +232,7 @@ void htmlrel()
          strcpy(name2,str2);
       }
    
-      sprintf(html,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s</td></tr>\n",text[89],periodo);
+      sprintf(html,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s</td></tr>\n",text[89],period);
       fputs(html,fp_ou);
       sprintf(html,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s</td></tr>\n",text[90],name2);
       fputs(html,fp_ou);
@@ -243,7 +243,7 @@ void htmlrel()
       fputs("<tr><td></td></tr>\n",fp_ou);
  
       fputs("</table></center>\n",fp_ou);
-      fputs("<center><table cellpadding=\"1\" cellspaging=\"2\">\n",fp_ou);
+      fputs("<center><table cellpadding=\"2\" cellspacing=\"1\">\n",fp_ou);
    
       if(strlen(denied_report) > 0) {
          sprintf(html,"<tr><td class=\"header\" colspan=11><a href=\"denied_%s.html\">%s</a> %s</td></tr>\n",denied_report,text[116],text[55]);
