@@ -127,6 +127,7 @@ char RemoveTempFiles[4];
 char ReplaceIndex[256];
 char Index[20];
 char OverwriteReport[4];
+char u2[255];
 char RecordsWithoutUser[20];
 char UseComma[4];
 char MailUtility[6];
@@ -142,6 +143,7 @@ char name[MAXLEN];
 char LongUrl[20];
 char Ip2Name[20];
 char language[255];
+char bufy[MAXLEN];
 char AccessLog[MAXLEN];
 char Title[MAXLEN];
 char BgColor[MAXLEN];
@@ -204,6 +206,7 @@ char SquidGuardLogFormat[MAXLEN];
 char SquidGuardLogAlternate[MAXLEN];
 char SquidguardIgnoreDate[10];
 char ShowSargInfo[5];
+char BytesInSitesUsersReport[10];
 char ShowSargLogo[5];
 char ParsedOutputLog[MAXLEN];
 char ParsedOutputLogCompress[255];
