@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -59,11 +59,9 @@ void mklastlog()
       local = localtime(&t);
       strftime(ftime, 127, "%Y%m%d%H%M%S", local);
       sprintf(buf,"%s %s\n",ftime,direntp->d_name);
-printf("BUF=%s\n",buf);
       fputs(buf,fp_ou);
       ftot++;
    }
-exit(0);
 
    (void)rewinddir( dirp );
    (void)closedir( dirp );
