@@ -217,6 +217,7 @@ int main(argc,argv)
    strcpy(DansguardianIgnoreDate,"off");
    strcpy(DataFileUrl,"ip");
    strcpy(MaxElapsed,"28800000");
+   strcpy(BytesInSitesUsersReport,"no");
 
    dia[0]='\0';
    mes[0]='\0';
@@ -421,44 +422,6 @@ int main(argc,argv)
       exit(0);
    }
 
-   if(debugz) {
-      fprintf(stderr, "SARG: ConfigFile.........= %s\n",ConfigFile);
-      fprintf(stderr, "SARG: AccessLog..........= %s\n",AccessLog);
-      fprintf(stderr, "SARG: BgColor............= %s\n",BgColor);
-      fprintf(stderr, "SARG: TxColor............= %s\n",TxColor);
-      fprintf(stderr, "SARG: TxBgColor..........= %s\n",TxBgColor);
-      fprintf(stderr, "SARG: TiColor............= %s\n",TiColor);
-      fprintf(stderr, "SARG: LogoImage..........= %s\n",LogoImage);
-      fprintf(stderr, "SARG: LogoText...........= %s\n",LogoText);
-      fprintf(stderr, "SARG: LogoTextColor......= %s\n",LogoTextColor);
-      fprintf(stderr, "SARG: Width..............= %s\n",Width);
-      fprintf(stderr, "SARG: Height.............= %s\n",Height);
-      fprintf(stderr, "SARG: Title..............= %s\n",Title);
-      fprintf(stderr, "SARG: BgImage............= %s\n",BgImage);
-      fprintf(stderr, "SARG: FontFace...........= %s\n",FontFace);
-      fprintf(stderr, "SARG: HeaderColor........= %s\n",HeaderColor);
-      fprintf(stderr, "SARG: HeaderBgColor......= %s\n",HeaderBgColor);
-      fprintf(stderr, "SARG: FontSize...........= %s\n",FontSize);
-      fprintf(stderr, "SARG: PasswdFile.........= %s\n",PasswdFile);
-      fprintf(stderr, "SARG: TempDir............= %s\n",TempDir);
-      fprintf(stderr, "SARG: OutputDir..........= %s\n",OutputDir);
-      fprintf(stderr, "SARG: Ip2Name............= %s\n",Ip2Name);
-      fprintf(stderr, "SARG: TopuserSortField.........= %s\n",TopuserSortField);
-      fprintf(stderr, "SARG: UserSortField.........= %s\n",UserSortField);
-      fprintf(stderr, "SARG: TopuserSortOrder.........= %s\n",TopuserSortOrder);
-      fprintf(stderr, "SARG: UserSortOrder.........= %s\n",UserSortOrder);
-      fprintf(stderr, "SARG: UserAgentLog.......= %s\n",UserAgentLog);
-      fprintf(stderr, "SARG: ExcludeHosts.......= %s\n",ExcludeHosts);
-      fprintf(stderr, "SARG: DateFormat.........= %s\n",DateFormat);
-      fprintf(stderr, "SARG: ExcludeUsers.......= %s\n",ExcludeUsers);
-      fprintf(stderr, "SARG: PerUserLimitFile...= %s\n",PerUserLimitFile);
-      fprintf(stderr, "SARG: PerUserLimit.......= %s\n",PerUserLimit);
-      fprintf(stderr, "SARG: UserIp.............= %s\n",UserIp);
-      fprintf(stderr, "SARG: MaxElapsed.........= %s\n",MaxElapsed);
-      fprintf(stderr, "SARG: LastLog............= %s\n",LastLog);
-      fprintf(stderr, "SARG:\n");
-   }
- 
    if(strcmp(IndexTree,"file") == 0)
       strcpy(ImageFile,"../images");
    else
