@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
+ *                                                            1998, 2005
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -46,12 +46,49 @@ realtime(int argc, char *argv[])
 
 void getlog()
 {
-   FILE *tmp, *fp;
+   FILE *tmp, *fp, *fp_usr;
    char template1[255]="/var/tmp/sargtpl1.XXXXXX";
    char template2[255]="/var/tmp/sargtpl2.XXXXXX";
    char cmd[512];
    char buf[512];
-   int fd1,fd2;
+   int  fd1,fd2,nreg;
+
+   if(UserTabFile[0] != '\0') {
+      if(debug) {
+         sprintf(msg,"%s: %s",text[86],UserTabFile);
+         debuga(msg);
+      }
+      if((fp_usr=fopen(UserTabFile,"r"))==NULL) {
+        fprintf(stderr, "SARG: (realtime) %s: %s - %s\n",text[45],UserTabFile,strerror(errno));
+        exit(1);
+      }
+      nreg = lseek(fileno(fp_usr), 0, SEEK_END);
+      lseek(fileno(fp_usr), 0, 0);
+      if((userfile=(char *) malloc(nreg+100))==NULL){
+         fprintf(stderr, "SARG ERROR: %s",text[87]);
+         exit(1);
+      }
+      bzero(userfile,nreg+100);
+      strncat(userfile,":",1);
+      z1=0;
+      z2=1;
+      while(fgets(buf,MAXLEN,fp_usr)!=NULL){
+        buf[strlen(buf)-1]='\0';
+        if(strstr(buf,"\r") != 0) buf[strlen(buf)-1]='\0';
+        getword(bufy,buf,' ');
+        for(z1=0; z1<=strlen(bufy); z1++) {
+           userfile[z2]=bufy[z1];
+           z2++;
+        }
+        strncat(userfile,":",1);
+        for(z1=0; z1<=strlen(buf); z1++) {
+           userfile[z2]=buf[z1];
+           z2++;
+        }
+        strncat(userfile,":",1);
+      }
+      fclose(fp_usr);
+   }
 
    fd1 = mkstemp(template1);
    fd2 = mkstemp(template2);
@@ -139,7 +176,29 @@ void datashow(char *tmp)
       if(strcmp(ouser,user) == 0 && strcmp(ourl,url) == 0)
          continue;
 
-      printf("<tr><td class=\"data\">%s %s</td><td class=\"data3\">%s</td><td class=\"data3\">%s</td><td class=\"data3\">%s</td><td class=\"data2\"><a href=\"http://%s\">%s</td></tr>\n",dat,tim,ip,user,typ,url,url);
+      strcpy(u2,user);
+      if(strcmp(Ip2Name,"yes") == 0)
+         ip2name(u2);
+      if(UserTabFile[0] != '\0') {
+         sprintf(warea,":%s:",u2);
+         if((str=(char *) strstr(userfile,warea)) != (char *) NULL ) {
+            z1=0;
+            str2=(char *) strstr(str+1,":");
+            str2++;
+            bzero(name, MAXLEN);
+            while(str2[z1] != ':') {
+               name[z1]=str2[z1];
+               z1++;
+            }
+         } else strcpy(name,u2);
+      } else strcpy(name,u2);
+
+      if(dotinuser && strstr(name,"_")) {
+         str2=(char *)subs(name,"_",".");
+         strcpy(name,str2);
+      }
+
+      printf("<tr><td class=\"data\">%s %s</td><td class=\"data3\">%s</td><td class=\"data3\">%s</td><td class=\"data3\">%s</td><td class=\"data2\"><a href=\"http://%s\">%s</td></tr>\n",dat,tim,ip,name,typ,url,url);
       strcpy(ouser,user);
       strcpy(ourl,url);
    }
