@@ -36,6 +36,7 @@ void siteuser()
    char ourl[MAXLEN];
    char nacc[20];
    char nbytes[20];
+   char obytes[20];
    char csort[255];
    char general[MAXLEN];
    char general2[MAXLEN];
@@ -47,6 +48,7 @@ void siteuser()
    int regs=0;
    int ucount=0;
    char *users;
+   long long int llbytes=0;
 
    if(strcmp(Privacy,"yes") == 0)
       return;
@@ -102,11 +104,14 @@ void siteuser()
 
    fputs("<center><table cellpadding=0 cellspacing=2>\n",fp_ou);
    fputs("<tr><td></td></tr>\n",fp_ou);
-   sprintf(url,"<tr><th class=\"header\">%s</th><th class=\"header\">%s</th><th class=\"header\">%s</th></tr>\n",text[100],text[91],text[103]);
+   if(strncmp(strlow(BytesInSitesUsersReport),"yes",3) == 0)
+      sprintf(url,"<tr><th class=\"header\">%s</th><th class=\"header\">%s</th><th class=\"header\">%s</th><th class=\"header\">%s</th></tr>\n",text[100],text[91],text[93],text[103]);
+   else sprintf(url,"<tr><th class=\"header\">%s</th><th class=\"header\">%s</th><th class=\"header\">%s</th></tr>\n",text[100],text[91],text[103]);
    fputs(url,fp_ou);
   
    user[0]='\0';
    ourl[0]='\0';
+   obytes[0]='\0';
 
    if((users=(char *) malloc(204800))==NULL){
       fprintf(stderr, "SARG: ERROR: %s",text[87]);
@@ -152,6 +157,7 @@ void siteuser()
 
       if(!regs) {
          strcpy(ourl,url);
+         strcpy(obytes,nbytes);
          regs++;
       }
       
@@ -176,13 +182,18 @@ void siteuser()
       else BlockImage[0]='\0';
 
       if(strcmp(url,ourl) != 0) {
-         sprintf(html,"<tr><td class=\"data\">%d</td><td class=\"data2\">%s<a href=\"http://%s\">%s</td><td class=\"data2\">%s</td></tr>\n",regs,BlockImage,ourl,ourl,users);
+         if(strncmp(strlow(BytesInSitesUsersReport),"yes",3) == 0) {
+            llbytes=my_atoll(obytes);
+            sprintf(wwork2,"%s",fixnum(llbytes,1));
+            sprintf(html,"<tr><td class=\"data\">%d</td><td class=\"data2\">%s<a href=\"http://%s\">%s</td><td class=\"data\">%s</td><td class=\"data2\">%s</td></tr>\n",regs,BlockImage,ourl,ourl,wwork2,users);
+         } else sprintf(html,"<tr><td class=\"data\">%d</td><td class=\"data2\">%s<a href=\"http://%s\">%s</td><td class=\"data2\">%s</td></tr>\n",regs,BlockImage,ourl,ourl,users);
          fputs(html,fp_ou);
          regs++;
          ucount=0;
 	 strcpy(users,name);
          strcat(users," ");
          strcpy(ourl,url);
+         strcpy(obytes,nbytes);
       }
    }
 
