@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -39,7 +39,7 @@ void smartfilter_report()
    char per[MAXLEN];
    char sites[MAXLEN];
    char report[MAXLEN];
-   char periodo[100];
+   char period[100];
    char ip[MAXLEN];
    char user[MAXLEN];
    char ouser[MAXLEN];
@@ -60,7 +60,7 @@ void smartfilter_report()
    sprintf(smart_in,"%s/smartfilter.unsort",dirname);
    sprintf(sites,"%s/sites",dirname);
    sprintf(smart_ou,"%s/smartfilter.log",dirname);
-   sprintf(per,"%s/periodo",dirname);
+   sprintf(per,"%s/period",dirname);
    sprintf(report,"%s/smartfilter.html",dirname);
 
    if ((fp_in = fopen(per, "r")) == 0) {
@@ -68,7 +68,7 @@ void smartfilter_report()
       exit(1);
    }
 
-   fgets(periodo,sizeof(periodo),fp_in);
+   fgets(period,sizeof(period),fp_in);
    fclose(fp_in);
 
    sprintf(csort,"sort -n -k 1,1 -k 2,2 -k 3,3 -o '%s' '%s'",smart_ou,smart_in);
@@ -85,47 +85,23 @@ void smartfilter_report()
      exit(1);
    }
 
-   fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_ou);
-   fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_ou);   
-   fputs("<html>\n",fp_ou);
-   fputs("<head>\n",fp_ou);
-   sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
-   fputs(html,fp_ou);
+   fprintf(fp_ou, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n<html>\n<head>\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
    fputs("</head>\n",fp_ou);
-
-   if(strlen(FontFace) > 0) {
-      sprintf(url,"<font face=%s>\n",FontFace);
-      fputs(url,fp_ou);
-   }
-
-   sprintf(url,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
-   fputs(url,fp_ou);
-
+   if(strlen(FontFace) > 0) fprintf(fp_ou,"<font face=%s>\n",FontFace);
+   fprintf(fp_ou,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
    fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
+   if(strlen(LogoImage) > 0) fprintf(fp_ou, "<center><table cellpadding=\"0\" cellspacing=\"0\">\n<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n<tr><td height=\"5\"></td></tr>\n</table>\n",LogoImage,Width,Height,LogoText);
 
-   if(strlen(LogoImage) > 0) {
-      fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ou);
-      sprintf(url,"<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n",LogoImage,Width,Height,LogoText);
-      fputs(url,fp_ou);
-      fputs("<tr><td height=\"5\"></td></tr>\n",fp_ou);
-      fputs("</table>\n",fp_ou);
-   }
-
-   sprintf(url,"<tr><th align=center><b><font color=%s size=+1>%s</font></b></th></tr>\n",TiColor,Title);
-   fputs(url,fp_ou);
-
-   sprintf(url,"<tr><td align=center bgcolor=%s><font size=%s>%s: %s</font></td></tr>\n",HeaderBgColor,FontSize,text[89],periodo);
-   fputs(url,fp_ou);
-   sprintf(url,"<tr><th bgcolor=%s align=center><font size=%s>%s %s</font></th></tr>\n",HeaderBgColor,FontSize,text[116],text[55]);
-   fputs(url,fp_ou);
+   fprintf(fp_ou,"<tr><th align=center><b><font color=%s size=+1>%s</font></b></th></tr>\n",TiColor,Title);
+   fprintf(fp_ou,"<tr><td align=center bgcolor=%s><font size=%s>%s: %s</font></td></tr>\n",HeaderBgColor,FontSize,text[89],period);
+   fprintf(fp_ou,"<tr><th bgcolor=%s align=center><font size=%s>%s</font></th></tr>\n",HeaderBgColor,FontSize,text[116]);
    fputs("</table></center>\n",fp_ou);
 
    fputs("<center><table cellpadding=0 cellspacing=2>\n",fp_ou);
    fputs("<tr><td></td></tr>\n",fp_ou);
    fputs("<tr><td></td></tr>\n",fp_ou);
    fputs("<tr><td></td></tr>\n",fp_ou);
-   sprintf(url,"<tr><th bgcolor=%s><font size=%s>%s</font></th><th bgcolor=%s><font size=%s>%s</font></th><th bgcolor=%s><font size=%s>%s</font></th><th bgcolor=%s><font size=%s>%s</font></th><th bgcolor=%s><font size=%s>%s</font></th></tr>\n",HeaderBgColor,FontSize,text[98],HeaderBgColor,FontSize,text[111],HeaderBgColor,FontSize,text[110],HeaderBgColor,FontSize,text[91],HeaderBgColor,FontSize,smartheader);
-   fputs(url,fp_ou);
+   fprintf(fp_ou,"<tr><th bgcolor=%s><font size=%s>%s</font></th><th bgcolor=%s><font size=%s>%s</font></th><th bgcolor=%s><font size=%s>%s</font></th><th bgcolor=%s><font size=%s>%s</font></th><th bgcolor=%s><font size=%s>%s</font></th></tr>\n",HeaderBgColor,FontSize,text[98],HeaderBgColor,FontSize,text[111],HeaderBgColor,FontSize,text[110],HeaderBgColor,FontSize,text[91],HeaderBgColor,FontSize,smartheader);
 
    while(fgets(buf,sizeof(buf),fp_in)!=NULL) {
       getword(user,buf,' ');
@@ -175,16 +151,10 @@ void smartfilter_report()
          sprintf(html2,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
          fputs(html2,fp_user);
          fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_user);
-         if(strlen(LogoImage) > 0) {
-            sprintf(html2,"<tr><th align=left><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
-            fputs(html2,fp_user);
-         }
-         sprintf(html2,"<tr><th align=center><b><font color=%s size=+1>%s</font></b></th></tr>\n",TiColor,Title);
-         fputs(html2,fp_user);
-         sprintf(html2,"<tr><td align=center bgcolor=%s><font size=%s>%s: %s</font></td></tr>\n",HeaderBgColor,FontSize,text[89],periodo);
-         fputs(html2,fp_user);
-         sprintf(html2,"<tr><td align=center bgcolor=%s><font size=%s>%s:</font><font size=%s> %s</font></td></tr>\n",HeaderBgColor,FontSize,text[90],FontSize,user);
-         fputs(html2,fp_user);
+         if(strlen(LogoImage) > 0) fprintf(fp_user,"<tr><th align=left><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
+         fprintf(fp_user,"<tr><th align=center><b><font color=%s size=+1>%s</font></b></th></tr>\n",TiColor,Title);
+         fprintf(fp_user,"<tr><td align=center bgcolor=%s><font size=%s>%s: %s</font></td></tr>\n",HeaderBgColor,FontSize,text[89],period);
+         fprintf(fp_user,"<tr><td align=center bgcolor=%s><font size=%s>%s:</font><font size=%s> %s</font></td></tr>\n",HeaderBgColor,FontSize,text[90],FontSize,user);
          fputs("</table></center>\n",fp_user);
          fputs("<center><table cellpadding=0 cellspacing=2>\n",fp_user);
          fputs("<tr><td></td></tr>\n",fp_user);
