@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -139,6 +139,11 @@ void sort_users_log(char *tmp, int debug)
          goto strip_unsort;
       }
 
+      if(debug) {
+         sprintf(msg,"%s %s/%s.unsort",text[54],wtmp,user);
+         debuga(msg);
+      }
+
       if(strcmp(direntp->d_name,"download.unsort") == 0)
          sprintf(csort,"sort -T %s -k 3,3 -k 1,1 -k 2,2 -k 5,5 -o '%s/%s.log' '%s/%s.unsort'",
 					tmp, wtmp, user, wtmp, user);
