@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -147,28 +147,28 @@ int squidguard_log()
 
    if(strcmp(SquidguardIgnoreDate,"on") == 0) {
       if(strcmp(df,"e") == 0) {
-         strncpy(day,periodo,2);
-         strncpy(mon,periodo+2,3);
-         strncpy(year,periodo+5,4);
+         strncpy(day,period,2);
+         strncpy(mon,period+2,3);
+         strncpy(year,period+5,4);
          conv_month(mon);
          sprintf(warea,"%s%s%s",year,mon,day);
          dfrom=atoi(warea);
-         strncpy(day,periodo+10,2);
-         strncpy(mon,periodo+12,3);
-         strncpy(year,periodo+15,4);
+         strncpy(day,period+10,2);
+         strncpy(mon,period+12,3);
+         strncpy(year,period+15,4);
          conv_month(mon);
          sprintf(warea,"%s%s%s",year,mon,day);
          duntil=atoi(warea);
       } else {
-         strncpy(day,periodo+7,2);
-         strncpy(mon,periodo+4,3);
-         strncpy(year,periodo,4);
+         strncpy(day,period+7,2);
+         strncpy(mon,period+4,3);
+         strncpy(year,period,4);
          conv_month(mon);
          sprintf(warea,"%s%s%s",year,mon,day);
          dfrom=atoi(warea);
-         strncpy(day,periodo+17,2);
-         strncpy(mon,periodo+14,3);
-         strncpy(year,periodo+10,4);
+         strncpy(day,period+17,2);
+         strncpy(mon,period+14,3);
+         strncpy(year,period+10,4);
          conv_month(mon);
          sprintf(warea,"%s%s%s",year,mon,day);
          duntil=atoi(warea);
@@ -204,6 +204,14 @@ int squidguard_log()
                   y++;
                }
             }
+            if(strchr(str2,' ') != 0) {
+               getword(warea,str2,' ');
+               strcpy(str2,warea);
+            }
+            if(strchr(str2,'#') != 0) {
+               getword(warea,str2,'#');
+               strcpy(str2,warea);
+            }
             sprintf(wentp,"%s/%s",logdir,str2);
             read_log(wentp,fp_ou);
          }
