@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -40,14 +40,13 @@ void topsites()
    char ttnbytes[20];
    char ttntime[20];
    char csort[255];
-   char geral[MAXLEN];
-   char geral2[MAXLEN];
-   char geral3[MAXLEN];
+   char general[MAXLEN];
+   char general2[MAXLEN];
+   char general3[MAXLEN];
    char per[MAXLEN];
    char sites[MAXLEN];
    char report[MAXLEN];
-   char periodo[100];
-   char ftime[128];
+   char period[100];
    char sortf[10];
    char sortt[10];
    long long int tnacc=0;
@@ -56,12 +55,14 @@ void topsites()
    long long int twork1=0, twork2=0, twork3=0;
    int regs=0;
 
+   if(strcmp(Privacy,"yes") == 0)
+      return;
 
-   sprintf(geral,"%s/geral",dirname);
+   sprintf(general,"%s/general",dirname);
    sprintf(sites,"%s/sites",dirname);
-   sprintf(geral2,"%s/geral2",dirname);
-   sprintf(geral3,"%s/geral3",dirname);
-   sprintf(per,"%s/periodo",dirname);
+   sprintf(general2,"%s/general2",dirname);
+   sprintf(general3,"%s/general3",dirname);
+   sprintf(per,"%s/period",dirname);
 
    if (strstr(ReportType,"topusers") == 0)
       sprintf(report,"%s/index.html",dirname);
@@ -73,19 +74,19 @@ void topsites()
       exit(1);
    }
 
-   fgets(periodo,sizeof(periodo),fp_in);
+   fgets(period,sizeof(period),fp_in);
    fclose(fp_in);
 
-   sprintf(csort,"sort -k 4,4 -o '%s' '%s'",geral2,geral);
+   sprintf(csort,"sort -k 4,4 -o '%s' '%s'",general2,general);
    system(csort);
 
-   if((fp_in=fopen(geral2,"r"))==NULL) {
-     fprintf(stderr, "SARG: (topsite) %s: %s\n",text[8],geral2);
+   if((fp_in=fopen(general2,"r"))==NULL) {
+     fprintf(stderr, "SARG: (topsite) %s: %s\n",text[8],general2);
      exit(1);
    }
 
-   if((fp_ou=fopen(geral3,"w"))==NULL) {
-     fprintf(stderr, "SARG: (topsite) %s: %s\n",text[8],geral3);
+   if((fp_ou=fopen(general3,"w"))==NULL) {
+     fprintf(stderr, "SARG: (topsite) %s: %s\n",text[8],general3);
      exit(1);
    }
 
@@ -135,7 +136,7 @@ void topsites()
 
    fclose(fp_in);
    fclose(fp_ou);
-   unlink(geral2);
+   unlink(general2);
 
    strlow(TopsitesSortField);
    strlow(TopsitesSortType);
@@ -149,11 +150,11 @@ void topsites()
    if(strcmp(TopsitesSortType,"d") == 0)
       strcpy(sortt,"-r");
 
-   sprintf(csort,"sort %s -k %s -o '%s' '%s'",sortt,sortf,sites,geral3);
+   sprintf(csort,"sort %s -k %s -o '%s' '%s'",sortt,sortf,sites,general3);
    system(csort);
 
-   unlink(geral2);
-   unlink(geral3);
+   unlink(general2);
+   unlink(general3);
 
    if((fp_in=fopen(sites,"r"))==NULL) {
      fprintf(stderr, "SARG: (topsite) %s: %s\n",text[8],sites);
@@ -167,25 +168,11 @@ void topsites()
 
    regs=0;
 
-   fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_ou);
-   fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_ou);
-   fputs("<html>\n",fp_ou);
-   fputs("<head>\n",fp_ou);
-   sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
-   fputs(html,fp_ou);
+   fprintf(fp_ou, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n<html>\n<head>\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
    css(fp_ou);
    fputs("</head>\n",fp_ou);
-
-   sprintf(url,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
-   fputs(url,fp_ou);
-
-   if(strlen(LogoImage) > 0) {
-      fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ou);
-      sprintf(url,"<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n",LogoImage,Width,Height,LogoText);
-      fputs(url,fp_ou);
-      fputs("<tr><td height=\"5\"></td></tr>\n",fp_ou);
-      fputs("</table>\n",fp_ou);
-   }
+   fprintf(fp_ou,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
+   if(strlen(LogoImage) > 0) fprintf(fp_ou, "<center><table cellpadding=\"0\" cellspacing=\"0\">\n<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n<tr><td height=\"5\"></td></tr>\n</table>\n",LogoImage,Width,Height,LogoText);
 
    if(strcmp(IndexTree,"date") == 0)
       show_sarg(fp_ou,"../../..");
@@ -196,15 +183,15 @@ void topsites()
    sprintf(url,"<tr><th class=\"title\">%s</th></tr>\n",Title);
    fputs(url,fp_ou);
 
-   sprintf(url,"<tr><td class=\"header3\">%s: %s</td></tr>\n",text[89],periodo);
+   sprintf(url,"<tr><td class=\"header3\">%s: %s</td></tr>\n",text[89],period);
    fputs(url,fp_ou);
-   sprintf(url,"<tr><td class=\"header3\">%s %s %s</td></tr>\n",text[83],TopSitesNum,text[84]);
+   sprintf(url,"<tr><th class=\"header3\">%s %s %s</th></tr>\n",text[83],TopSitesNum,text[84]);
    fputs(url,fp_ou);
    fputs("</table></center>\n",fp_ou);
 
    fputs("<center><table cellpadding=\"1\" cellspacing=\"2\">\n",fp_ou);
    fputs("<tr><td></td></tr>\n",fp_ou);
-   sprintf(url,"<tr><td class=\"header\">%s</td><th class=\"header\">%s</th> \
+   sprintf(url,"<tr><th class=\"header\">%s</th><th class=\"header\">%s</th> \
 		<th class=\"header\">%s</th><th class=\"header\">%s</th> \
 		<th class=\"header\">%s</th></tr>\n", \
 		text[100],text[91],text[92],text[93],text[99]);
