@@ -367,7 +367,8 @@ int topuser()
 	 unlink(val1);
       }
 
-      if(UserTabFile[0] != '\0' && strstr(user2,".") != 0) {
+//      if(UserTabFile[0] != '\0' && strstr(user2,".") != 0) {
+      if(UserTabFile[0] != '\0') {
          sprintf(warea,":%s:",user2);
          if((str=(char *) strstr(userfile,warea)) != (char *) NULL ) {
             z1=0;
