@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -54,7 +54,7 @@ void useragent()
    ipantes[0]='\0';
    nameantes[0]='\0';
 
-   sprintf(hfile,"%s/%s/useragent.html", outdir,periodo);
+   sprintf(hfile,"%s/%s/useragent.html", outdir,period);
 
    sprintf(tmp,"%s/squagent.unsort",TempDir);
    sprintf(tmp2,"%s/squagent.log",TempDir);
@@ -136,29 +136,11 @@ void useragent()
    if(debug)
       debuga(text[72]);
 
-   fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_ht);
-   fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_ht);
-   fputs("<html>\n",fp_ht);
-   fputs("<head>\n",fp_ht);
-   sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
-   fputs(html,fp_ht);
+   fprintf(fp_ht, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n<html>\n<head>\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
    fputs("</head>\n",fp_ht);
-
-   if(strlen(FontFace) > 0) {
-      sprintf(html,"<font face=%s>\n",FontFace);
-      fputs(html,fp_ht);
-   }
-
-   sprintf(html,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
-   fputs(html,fp_ht);
-
-   if(strlen(LogoImage) > 0) {
-      fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ht);
-      sprintf(html,"<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n",LogoImage,Width,Height,LogoText);
-      fputs(html,fp_ht);
-      fputs("<tr><td height=\"5\"></td></tr>\n",fp_ht);
-      fputs("</table>\n",fp_ht);
-   }
+   if(strlen(FontFace) > 0) fprintf(fp_ht,"<font face=%s>\n",FontFace);
+   fprintf(fp_ht,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
+   if(strlen(LogoImage) > 0) fprintf(fp_ht, "<center><table cellpadding=\"0\" cellspacing=\"0\">\n<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n<tr><td height=\"5\"></td></tr>\n</table>\n",LogoImage,Width,Height,LogoText);
 
    if(strcmp(IndexTree,"date") == 0)
       show_sarg(fp_ht, "../../..");
