@@ -977,7 +977,13 @@ char *subs(char *str, char *from, char *to)
       return (char *) str;
 
     ss = strlen(str); st = strlen(to) + 10;
-    ret = (char *) malloc(ss + st);
+
+    if((ret=(char *) malloc(ss + st))==NULL)
+    {
+     fprintf(stderr, "SARG: %s (%d):\n",text[59],ss+st);
+     exit(1);
+    }
+
     bzero(ret,ss+st);
 
     tmp = strstr(str, from);
